@@ -36,8 +36,6 @@ pub trait SpendBook: std::fmt::Debug + Clone {
         dbc_hash: DbcContentHash,
         transaction: DbcTransaction,
     ) -> Result<(), Self::Error>;
-
-    fn entries(&self) -> Box<dyn Iterator<Item = (&DbcContentHash, &DbcTransaction)> + '_>;
 }
 
 #[derive(Debug, Default, Clone, Serialize, Deserialize)]
@@ -60,9 +58,23 @@ impl SpendBook for SimpleSpendBook {
         self.transactions.insert(dbc_hash, transaction);
         Ok(())
     }
+}
 
-    fn entries(&self) -> Box<dyn Iterator<Item = (&DbcContentHash, &DbcTransaction)> + '_> {
-        Box::new(self.transactions.iter())
+impl<'a> IntoIterator for &'a SimpleSpendBook {
+    type Item = (&'a DbcContentHash, &'a DbcTransaction);
+    type IntoIter = std::collections::btree_map::Iter<'a, DbcContentHash, DbcTransaction>;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.transactions.iter()
+    }
+}
+
+impl IntoIterator for SimpleSpendBook {
+    type Item = (DbcContentHash, DbcTransaction);
+    type IntoIter = std::collections::btree_map::IntoIter<DbcContentHash, DbcTransaction>;
+
+    fn into_iter(self) -> Self::IntoIter {
+        self.transactions.into_iter()
     }
 }
 
